"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, {
  Postgres,
  escapeId,
  escape,
  fullJitter,
  executeStatement,
  coercer
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName;

  const log = (0, _getLog.default)('connect');
  log.debug('configuring postgres client');
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  Object.assign(pool, {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    connectionOptions,
    Postgres,
    fullJitter,
    coercer,
    executeStatement: executeStatement.bind(null, pool),
    escapeId,
    escape
  });

  if (pool.executeStatement != null) {
    await pool.executeStatement('SELECT 0 AS "defunct"');
  }

  log.debug('connection to postgres databases established');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map