"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = _interopRequireDefault(require("./get-log"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const getSecret = async (pool, selector) => {
  const log = (0, _getLog.default)('secretsManager:getSecret');
  log.debug(`retrieving secret value from the database`);
  const {
    databaseName,
    secretsTableName,
    escapeId,
    executeStatement,
    escape
  } = pool; // TODO: refactor

  if (!secretsTableName || !escapeId || !databaseName || !executeStatement || !escape) {
    const error = Error(`adapter pool was not initialized properly!`);
    log.error(error.message);
    log.verbose(error.stack || error.message);
    throw error;
  }

  log.verbose(`selector: ${selector}`);
  log.verbose(`databaseName: ${databaseName}`);
  log.verbose(`secretsTableName: ${secretsTableName}`);
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const sql = `
    SELECT "secret" 
    FROM ${databaseNameAsId}.${secretsTableNameAsId} 
    WHERE "id"=${escape(selector)} LIMIT 1;`;
  log.debug(`executing SQL query`);
  log.verbose(sql);
  const rows = await executeStatement(sql);
  log.debug(`query executed, returning result`);
  const {
    secret
  } = rows && rows.length ? rows[0] : {
    secret: null
  };
  return secret;
};

var _default = getSecret;
exports.default = _default;
//# sourceMappingURL=get-secret.js.map